<h1 align="center">Akaneko</h1>
<h2 align="center">Python wrapper from <a href="https://www.npmjs.com/package/akaneko">Akaneko NodeJS wrapper</a></h3>
<h3 align="center"><a href="https://github.com/RaphielHS/akaneko-wrapper">Repository</a></h3>
<h3 align="center">Functions</h3>
<h3>SFW Functions - Safe For Work</h3>
	<h3>- neko</h3>
	<h3>- sfwfoxes</h3>
	<h3>- wallpaper</h3>
	<h3>- mobileWallpapers</h3>
	<h3>Usage : akaneko.neko()</h3>
<h3>NSFW Functions - Not Safe For Work</h3>
	<h3>- lewdneko</h3>
	<h3>- ass</h3>
	<h3>- bdsm</h3>
	<h3>- cum</h3>
	<h3>- doujin</h3>
	<h3>- femdom</h3>
	<h3>- hentai</h3>
	<h3>- maid</h3>
	<h3>- orgy</h3>
	<h3>- panties</h3>
	<h3>- wallpaper</h3>
	<h3>- mobilewallpapers</h3>
	<h3>- cuckhold</h3>
	<h3>- netorare</h3>
	<h3>- gifs / gif</h3>
	<h3>- blowjob</h3>
	<h3>- feet</h3>
	<h3>- pussy</h3>
	<h3>- uglyBastard</h3>
	<h3>- uniform</h3>
	<h3>- gangbang</h3>
	<h3>- foxgirl</h3>
	<h3>- cumslut</h3>
	<h3>- glasses</h3>
	<h3>- thighs</h3>
	<h3>- tentacles</h3>
	<h3>- loli</h3>
	<h3>- masturbatio</h3>
	<h3>- school</h3>
	<h3>- yuri</h3>
	<h3>- zettaiRyouiki</h3>
	<h3>Usage : akaneko.nsfw.lewdneko()</h3>
